<img height="100" src="https://raw.githubusercontent.com/meherett/swap/master/docs/static/svg/swap.svg">

[![Build Status](https://travis-ci.org/meherett/swap.svg?branch=master)](https://travis-ci.org/meherett/swap?branch=master)
[![PyPI Version](https://img.shields.io/pypi/v/swap.svg?color=blue)](https://pypi.org/project/swap)
[![Documentation Status](https://readthedocs.org/projects/crypto-swap/badge/?version=latest)](https://crypto-swap.readthedocs.io/en/latest/?badge=latest)
[![PyPI Python Version](https://img.shields.io/pypi/pyversions/swap.svg)](https://pypi.org/project/swap)
[![Coverage Status](https://coveralls.io/repos/github/meherett/swap/badge.svg?branch=master&kill_cache=1)](https://coveralls.io/github/meherett/swap?branch=master)

A Python library for a Cross-chain atomic swap between the networks of two cryptocurrencies. 
Cross-chain atomic swap is the cheapest and most secured by cryptographic proof to swap cryptocurrencies. 
It’s a brand new decentralized payment environment based on Hash Time Lock Contracts (HTLC's) protocol.

For more, Please read the [documentation](https://crypto-swap.readthedocs.io).

## Contributing

Feel free to open an [issue](https://github.com/meherett/swap/issues) if you find a problem, 
or a pull request if you've solved an issue. And also any help in testing, development, 
documentation and other tasks is highly appreciated and useful to the project. 
There are tasks for contributors of all experience levels.

For more information, see the [CONTRIBUTING.md](https://github.com/meherett/swap/blob/master/CONTRIBUTING.md) file.

## License

Distributed under the [AGPL-3.0](https://github.com/meherett/swap/blob/master/LICENSE) license. 
See ``LICENSE`` for more information.
